SessionManager class

Manages the session status of the user.

The SessionExpirationManager class is responsible for managing the session status of the user. It uses a stream to broadcast session status changes, allowing other parts of the application to listen for and react to these changes.

Constructors

SessionManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionStatus Stream<SessionStatus>
The stream to listen to the session status.
no setter

Methods

expireSession() → void
should be called after logout events
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startSession() → void
should be called after login or register events if user successfully logged in or registered
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited